import { env } from "@/utils/env";
import Database from "better-sqlite3";
import { drizzle } from "drizzle-orm/better-sqlite3";
import * as schema from "@/server/db/schema";

// Stellen sicher, dass DB_PATH tatsächlich gesetzt ist
const dbPath = env.DB_PATH || "/app/db/sqlite.db";

// Konfiguriere SQLite für zuverlässigeren Betrieb
const sqlite = new Database(dbPath, {
  // Setze längeres Timeout für Operationen auf langsamen Geräten (RPi)
  timeout: 30000,
  // Aktiviere WAL-Modus für höhere Performance
  journalMode: 'wal',
  // Verbesserte Fehlerbehandlung
  verbose: console.error,
});

// Aktiviere Fremdschlüssel-Constraints
sqlite.pragma('foreign_keys = ON');

// Exportiere die Drizzle-Datenbankinstanz
export const db = drizzle(sqlite, { schema });
